@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
+# ruff: noqa: SIM401  # _METADATA is not a dict and this doesn't work
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 #              C E D A R
@@ -44,7 +44,7 @@ Attributes:
 # information is not available in the package metadata.  These values are maintained to
 # avoid breaking the public interface, but are always "unset".
 
-from importlib_metadata import metadata
+from importlib.metadata import metadata
 
 try:
     _METADATA = metadata("cedar-backup3")
